# Python Windows SDK

Python bindings for the Windows SDK.

This is a community-supported version of the unmaintained [winrt] package.

[winrt]: https://pypi.org/project/winrt

## Documentation

Since the bindings are automatically generated, there are no API docs available.
Instead, use <https://docs.microsoft.com/en-us/uwp/api/> as a reference.

Also be sure to read the [pywinrt docs] that explain how the language projection
works.

[pywinrt docs]: https://github.com/pywinrt/pywinrt/blob/v1.0.0-beta.1/src/package/pywinrt/projection/readme.md
